# -*- coding: utf-8 -*-
from __future__ import unicode_literals


__version__ = '0.2.0'

DEFAULT_SOCAT_VERSION = '1.7.2.4'

DOCKER_LOG_FORMAT = "[{0}] docker: {1}"
SIMPLE_LOG_FORMAT = '[{0}] {1}'
